# Cryptography Library for MicroService Encryption

## Overview

Python cryptography library for [MSE](https://cosmian.com/microservice-encryption/) based on [PyNaCl](https://github.com/pyca/pynacl/) (binding to [libsodium](https://github.com/jedisct1/libsodium)) and [cryptography](https://github.com/pyca/cryptography).

## Installation

```console
$ pip install mse-lib-crypto
```
